@@ -29,6 +29,7 @@
 #' @param verbose Logical. If \code{TRUE}, the user keeps track of the main underlying operations. \code{TRUE} by default.s
 #' @param input_shp Object of class \code{sf}, \code{tbl_df}, \code{tbl}, \code{data.frame}. The relevant shapefiles of Italian administrative boudaries,
 #' at the selected level of detail (LAU or NUTS-3). If \code{NULL} it is downloaded automatically but not saved in the global environment. \code{NULL} by default.
+#' @param autoAbort Logical. In case any data must be retrieved, whether to automatically abort the operation and return NULL in case of missing internet connection or server response errors. \code{FALSE} by default.
 #' @param ... If \code{data} is not provided, the arguments to \code{\link{Group_DB_MIUR}}.
 #'
 #'
@@ -72,24 +73,26 @@ Map_School_Buildings <- function (data = NULL, field, order = NULL,  level = "LA
                                   region_code = c(1:20), plot = "mapview", pal = "Blues",
                                   col_rev = FALSE, popup_height = 200,
                                   main_pos = "top", main = "", verbose = TRUE,
-                                  input_shp = NULL, ... ) {
+                                  input_shp = NULL, autoAbort = FALSE, ... ) {
   options(dplyr.summarise.inform = FALSE)
 
   while(is.null(data)){
     if(verbose) cat("Loading input data: \n")
-    data <- Group_DB_MIUR(...)
+    data <- Group_DB_MIUR(autoAbort = autoAbort, ...)
     if(is.null(data)){
-      holdOn <- ""
-      message("Error during school buildings DB retrieving. Would you abort the whole operation or retry?",
-              "    - To abort the operation, press `A` \n",
-              "    - To retry data retrieving, press any other key \n")
-      holdOn <- readline(prompt = "    ")
-      if(toupper(holdOn) == "A"){
-        cat("You chose to abort the operation \n")
-        return(NULL)
-      } else {
-        cat("You chose to retry \n")
-      }
+      if(!autoAbort){
+        holdOn <- ""
+        message("Error during school buildings DB retrieving. Would you abort the whole operation or retry?",
+                "    - To abort the operation, press `A` \n",
+                "    - To retry data retrieving, press any other key \n")
+        holdOn <- readline(prompt = "    ")
+        if(toupper(holdOn) == "A"){
+          cat("You chose to abort the operation \n")
+          return(NULL)
+        } else {
+          cat("You chose to retry \n")
+        }
+      } else return(NULL)
     }
   }
 
@@ -121,19 +124,21 @@ Map_School_Buildings <- function (data = NULL, field, order = NULL,  level = "LA
     if (verbose) cat("Loading shapefile: \n")
     input_shp <- Get_Shapefile(Year = ifelse(
       any(year.patternA(Year) %in% c(year.patternA(2016), year.patternA(2018))), Year, YearMinus1),
-      level = level)
+      level = level, autoAbort = autoAbort)
     if(is.null(input_shp)){
-      holdOn <- ""
-      message("Error during shapefile retrieving. Would you abort the whole operation or retry?",
-              "    - To abort the operation, press `A` \n",
-              "    - To retry data retrieving, press any other key \n")
-      holdOn <- readline(prompt = "    ")
-      if(toupper(holdOn) == "A"){
-        cat("You chose to abort the operation \n")
-        return(NULL)
-      } else {
-        cat("You chose to retry \n")
-      }
+      if(!autoAbort){
+        holdOn <- ""
+        message("Error during shapefile retrieving. Would you abort the whole operation or retry?",
+                "    - To abort the operation, press `A` \n",
+                "    - To retry data retrieving, press any other key \n")
+        holdOn <- readline(prompt = "    ")
+        if(toupper(holdOn) == "A"){
+          cat("You chose to abort the operation \n")
+          return(NULL)
+        } else {
+          cat("You chose to retry \n")
+        }
+      } else return(NULL)
     }
   }
 
